﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using Cinemachine;

public class CharacterController2D : MonoBehaviour
{

    //Defining movement variables
    public float runSpeed;
    public Rigidbody2D rBody;
    public float jumpForce;
    

    //Defining variables used to check whether the character is on the ground
    public bool isGrounded = false;
    public Transform groundCheck;
    public float groundRadius = .00001f;
    public LayerMask ground;

    //Defining variables used to check whether the character is in range of certain interactables that are affected by notes
    public bool isInteract = false;
    public LayerMask interact;

    public bool facingRight = true;
    public Animator playerAnim;
    public Animator horseAnim;

    public GameObject cart;
    public bool isDriving;
    public bool cartProximity;

    public float fTimer = 1;
    public bool canF = true;

    public CinemachineVirtualCamera cineCamera;
    public GameObject cameratarget;

    public GameObject parallaxFar;
    public GameObject parallaxClose;
    public GameObject parallaxClouds;
    

    // Start is called before the first frame update
    void Start()
    {
        rBody = GetComponent<Rigidbody2D>();

       // playerAnim.GetComponent<Animator>();
    }

    void FixedUpdate()
    {
        //Sets up the players side to side movement using Unity's built in input system
        float move = Input.GetAxis("Horizontal");

        if (isDriving == false)
            rBody.velocity = new Vector2(move * runSpeed, rBody.velocity.y);
        else if (isDriving == true)
            rBody.velocity = new Vector2(Mathf.Abs(move)* runSpeed, rBody.velocity.y);

        //Creates two circles that checks for objects in the scene that are on the ground or interact layers and returns true or false depending on if the circle overlaps with those objects
        isGrounded = Physics2D.OverlapCircle(groundCheck.position, groundRadius, ground);
        //isInteract = Physics2D.OverlapCircle(noteCheckTransform.position, noteRadius, interact);

        if (move > 0 && !facingRight && isDriving == false)
        {
            playerAnim.SetBool("isWalking", true);
            Flip(move);
        }
        else if (move < 0 && facingRight && isDriving == false)
        {
            playerAnim.SetBool("isWalking", true);
            Flip(move);
        }
        else if (move == 0 && isDriving == false)
        {
            playerAnim.SetBool("isWalking", false);
        }
        else if (Mathf.Abs(move) > 0 && isDriving == true)
        {
            horseAnim.SetBool("isWalking", true);

        }
        else if (move == 0 && isDriving == true) 
        {
            horseAnim.SetBool("isWalking", false);
        }

       // if (move != 0)
            //playerAnim.SetBool("isWalking", true);

    }

    // Update is called once per frame
    void Update()
    {
        Fbuffer();
        
        
        //If the jump button (or alternatively the up button) is pressed add a vertical force to the character allowing them to jump
        if (isGrounded && (Input.GetButton("Jump") || Input.GetAxis("Vertical") > 0))
        {
            rBody.velocity = new Vector2(0f, jumpForce);
        }

       if (Input.GetKey(KeyCode.F) && canF)
        {
            if (isDriving == false && cartProximity)
            {
                fTimer = 1f;
                //move player to seat
                gameObject.transform.position = cart.transform.position + new Vector3(1.8f, .5f, 0f);

                if (!facingRight)
                {
                    Flip(1);
                }

                //freeze y position
                rBody.constraints = RigidbodyConstraints2D.FreezePositionY;

                //set cart & giraffe as children
                cart.transform.parent = gameObject.transform;
                isDriving = true;
                runSpeed = 2;

                cineCamera.Follow = gameObject.transform;




            }
            else if (isDriving == true)
            {
                fTimer = 1f;
                //remove giraffe and cart as children
                cart.transform.parent = null;

                //move player out of seat
                gameObject.transform.position = cart.transform.position + new Vector3(1.8f, .3f, 0f);

                //unfreeze y position and readd rotation freeze
                rBody.constraints = RigidbodyConstraints2D.None;
                rBody.constraints = RigidbodyConstraints2D.FreezeRotation;

                isDriving = false;
                runSpeed = 3;


                cineCamera.Follow = cameratarget.transform;
            }
        }

        Parallax();

    }

    //This code fires when another trigger colliders collide with the player 
    private void OnTriggerEnter2D(Collider2D other)
    {
        if (other.gameObject.CompareTag("Cart")) //if the player collides with a coin then the coin disappears giving the illusion of collecting the coin
        {
            cartProximity = true;
        } 

    }
    private void OnTriggerExit2D(Collider2D other)
    {
        if (other.gameObject.CompareTag("Cart")) //if the player collides with a coin then the coin disappears giving the illusion of collecting the coin
        {
            cartProximity = false;
        } 

    }

    private void Flip(float horizontal)
    {
        facingRight = !facingRight;
        Vector3 theScale = transform.localScale;
        theScale.x *= -1;
        transform.localScale = theScale;
    }


    void Fbuffer()
    {

        if (isDriving == true)
        {
            fTimer -= Time.deltaTime;
            canF = false;

            if (fTimer <= 0f)
            {
                canF = true;

                
            }
        }
        else if (isDriving == false)
        {
            fTimer -= Time.deltaTime;
            canF = false;

            if (fTimer <= 0f)
            {
                canF = true;

                
            }
        }

        
    }

    void Parallax()
    {
        Vector3 movement1 = new Vector3(.05f * (rBody.velocity.x * -1), 0, 0);
        Vector3 movement2 = new Vector3(.1f * (rBody.velocity.x * -1), 0, 0);
        Vector3 movement3 = new Vector3(.2f * (rBody.velocity.x * -1), 0, 0);

        movement1 *= Time.deltaTime;
        movement2 *= Time.deltaTime;
        movement3 *= Time.deltaTime;

        parallaxFar.transform.Translate(movement1);
        parallaxClose.transform.Translate(movement2);
        parallaxClouds.transform.Translate(movement3);
        
    }



}
